.. pyhwloc documentation master file, created by
   sphinx-quickstart on Sun Aug 17 22:39:09 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pyhwloc documentation
=====================

**pyhwloc** is a Python interface of the hwloc library.


.. toctree::
  :maxdepth: 2
  :titlesonly:

  intro
  build
  examples/index
  pyhwloc_api
  low_level
  c
  dev
